@@ -44,7 +44,7 @@ static int attrib_file(direntry_t *entry, MainParam_t *mp)
 	return GOT_ONE;
 }
 
-static int replay_attrib(direntry_t *entry, MainParam_t *mp)
+static int replay_attrib(direntry_t *entry, MainParam_t *mp UNUSEDP)
 {
 	if ( (IS_ARCHIVE(entry) && IS_DIR(entry)) ||
 		 (!IS_ARCHIVE(entry) && !IS_DIR(entry)) ||
@@ -76,7 +76,7 @@ static int replay_attrib(direntry_t *entry, MainParam_t *mp)
 
 
 
-static int view_attrib(direntry_t *entry, MainParam_t *mp)
+static int view_attrib(direntry_t *entry, MainParam_t *mp UNUSEDP)
 {
 	printf("  ");
 	if(IS_ARCHIVE(entry))
@@ -159,8 +159,8 @@ static int letterToCode(int letter)
 	}
 }
 
-
-void mattrib(int argc, char **argv, int type)
+void mattrib(int argc, char **argv, int type UNUSEDP) NORETURN;
+void mattrib(int argc, char **argv, int type UNUSEDP)
 {
 	Arg_t arg;
 	int view;
@@ -168,6 +168,7 @@ void mattrib(int argc, char **argv, int type)
 	int concise;
 	int replay;
 	char *ptr;
+	int wantUsage;
 
 	arg.add = 0;
 	arg.remove = 0xff;
@@ -176,16 +177,20 @@ void mattrib(int argc, char **argv, int type)
 	view = 0;
 	concise = 0;
 	replay = 0;
-	
+	wantUsage = 0;
+
 	if(helpFlag(argc, argv))
 		usage(0);
-	while ((c = getopt(argc, argv, "i:/ahrsAHRSXph")) != EOF) {
+	while ((c = getopt(argc, argv, "i:/ahrsAHRSXp")) != EOF) {
 		switch (c) {
+			case 'h':
+				wantUsage = 1;
+				/* FALL THROUGH */
 			default:
 				arg.remove &= ~letterToCode(c);
 				break;
 			case 'i':
-				set_cmd_line_image(optarg, 0);
+				set_cmd_line_image(optarg);
 				break;
 			case 'p':
 				replay = 1;
@@ -196,13 +201,15 @@ void mattrib(int argc, char **argv, int type)
 			case 'X':
 				concise = 1;
 				break;
-			case 'h':
-				usage(0);
 			case '?':
 				usage(1);
 		}
 	}
 
+	if(optind == argc && wantUsage) {
+		usage(0);
+	}
+
 	for(;optind < argc;optind++) {
 		switch(argv[optind][0]) {
 			case '+':
