@@ -76,6 +76,7 @@ static void usage(int ret)
  * @returns n.a.
  *
  */
+static void do_mclasserase(char drive,int debug) NORETURN;
 static void do_mclasserase(char drive,int debug)
 {
   struct device dev;		/* Device information structure */
@@ -90,7 +91,7 @@ static void do_mclasserase(char drive,int debug)
   
   char cCardType[12];
   
-  char drivel[2];		/* Stores the drive letter */
+  char drivel[3];		/* Stores the drive letter */
 
 
   int i = 0;
@@ -101,8 +102,9 @@ static void do_mclasserase(char drive,int debug)
   int icount=0;
   int iTotalErase = 0;
 
-  const int cycles = 3;		/* How many times we'll overwrite the media */
-  char odat[cycles];		/* Data for each overwrite procedure */
+/* How many times we'll overwrite the media: */
+#define CYCLES 3
+  unsigned char odat[CYCLES];	/* Data for each overwrite procedure */
 
   /* Creating values for overwrite  */
   odat[0]=0xff;
@@ -111,7 +113,7 @@ static void do_mclasserase(char drive,int debug)
   
 
   if (debug == 1)
-     printf("cycles: %i, odats: %i,%i,%i\n",cycles,odat[0],odat[1],odat[2]);
+     printf("cycles: %i, odats: %i,%i,%i\n",CYCLES,odat[0],odat[1],odat[2]);
   
   
 
@@ -144,7 +146,7 @@ static void do_mclasserase(char drive,int debug)
   }
       
   /* Forming cat command to overwrite the medias content. */
-  sprintf( drivel, "%c:", tolower(drive) );
+  sprintf( drivel, "%c:", ch_tolower(drive) );
 
 #if 0
   media_sectors = dev.tracks * dev.sectors;
@@ -159,7 +161,7 @@ static void do_mclasserase(char drive,int debug)
   /*
    * Overwrite device
    */
-  for( i=0; i < cycles; i++){
+  for( i=0; i < CYCLES; i++){
 
      if (debug==1)
      {
@@ -276,7 +278,8 @@ static void do_mclasserase(char drive,int debug)
  *
  *
  */
-void mclasserase(int argc, char **argv, int type)
+void mclasserase(int argc, char **argv, int type UNUSEDP) NORETURN;
+void mclasserase(int argc, char **argv, int type UNUSEDP)
 {
   /* declaration of all variables */
   int c;
@@ -284,7 +287,7 @@ void mclasserase(int argc, char **argv, int type)
   /* char* tempFilePath=NULL; */
   char drive='a';
 
-  int extern optind;
+  extern int optind;
 
   destroy_privs();
 
@@ -336,7 +339,7 @@ void mclasserase(int argc, char **argv, int type)
      {
        usage(1);
      }
-     drive = toupper(argv[optind][0]);
+     drive = ch_toupper(argv[optind][0]);
    }
   }
 #ifdef DEBUG
@@ -346,6 +349,4 @@ void mclasserase(int argc, char **argv, int type)
    * not exist */
   
   do_mclasserase(drive,debug);
-  
-  exit (0);
 }
