@@ -1,4 +1,20 @@
-/*
+/*  Copyright 1986-1992 Emmet P. Gray.
+ *  Copyright 1996-2002,2005,2008,2009 Alain Knaff.
+ *  This file is part of mtools.
+ *
+ *  Mtools is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Mtools is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with Mtools.  If not, see <http://www.gnu.org/licenses/>.
+ *
  * mdel.c
  * Delete an MSDOS file
  *
@@ -11,6 +27,7 @@
 #include "mainloop.h"
 #include "fs.h"
 #include "file.h"
+#include "file_name.h"
 
 typedef struct Arg_t {
 	int deltype;
@@ -56,10 +73,13 @@ static int del_entry(direntry_t *entry, MainParam_t *mp)
 		fputc('\n', stderr);
 	}
 
-	if ((entry->dir.attr & (ATTR_READONLY | ATTR_SYSTEM)) &&
-	    (ask_confirmation("%s: \"%s\" is read only, erase anyway (y/n) ? ",
-			      progname, entry->name)))
-		return ERROR_ONE;
+	if (entry->dir.attr & (ATTR_READONLY | ATTR_SYSTEM)) {
+		char tmp[4*MAX_VNAMELEN+1];
+		wchar_to_native(entry->name,tmp,MAX_VNAMELEN);
+		if (ask_confirmation("%s: \"%s\" is read only, erase anyway (y/n) ? ",
+				     progname, tmp))
+			return ERROR_ONE;
+	}
 	if (fatFreeWithDirentry(entry)) 
 		return ERROR_ONE;
 
@@ -75,14 +95,14 @@ static int del_file(direntry_t *entry, MainParam_t *mp)
 	Arg_t *arg = (Arg_t *) mp->arg;
 	MainParam_t sonmp;
 	int ret;
-	int r;
+	int r;	
 
 	sonmp = *mp;
 	sonmp.arg = mp->arg;
 
 	r = 0;
 	if (IS_DIR(entry)){
-		/* a directory */
+		/* a directory */		
 		SubDir = OpenFileByDirentry(entry);
 		initializeDirentry(&subEntry, SubDir);
 		ret = 0;
@@ -119,16 +139,17 @@ static int del_file(direntry_t *entry, MainParam_t *mp)
 	return del_entry(entry, mp);
 }
 
-
-static void usage(void)
+static void usage(int ret) NORETURN;
+static void usage(int ret)
 {
 	fprintf(stderr, 
 		"Mtools version %s, dated %s\n", mversion, mdate);
 	fprintf(stderr, 
 		"Usage: %s [-v] msdosfile [msdosfiles...]\n", progname);
-	exit(1);
+	exit(ret);
 }
 
+void mdel(int argc, char **argv, int deltype) NORETURN;
 void mdel(int argc, char **argv, int deltype)
 {
 	Arg_t arg;
@@ -136,21 +157,25 @@ void mdel(int argc, char **argv, int deltype)
 	int c,i;
 
 	arg.verbose = 0;
-	while ((c = getopt(argc, argv, "i:v")) != EOF) {
+	if(helpFlag(argc, argv))
+		usage(0);
+	while ((c = getopt(argc, argv, "i:vh")) != EOF) {
 		switch (c) {
 			case 'i':
-				set_cmd_line_image(optarg, 0);
+				set_cmd_line_image(optarg);
 				break;
 			case 'v':
 				arg.verbose = 1;
 				break;
+			case 'h':
+				usage(0);
 			default:
-				usage();
+				usage(1);
 		}
 	}
 
 	if(argc == optind)
-		usage();
+		usage(1);
 
 	init_mp(&mp);
 	mp.callback = del_file;
@@ -170,7 +195,8 @@ void mdel(int argc, char **argv, int deltype)
 	}
 	mp.lookupflags |= NO_DOTS;
 	for(i=optind;i<argc;i++) {
-		int b,l;
+		int b;
+		size_t l;
 		if(argv[i][0] && argv[i][1] == ':')
 			b = 2;
 		else
