@@ -1,12 +1,25 @@
-/*
+/*  Copyright 1996-1998,2000-2002,2005,2007-2009 Alain Knaff.
+ *  This file is part of mtools.
+ *
+ *  Mtools is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Mtools is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with Mtools.  If not, see <http://www.gnu.org/licenses/>.
+ *
  * mmove.c
  * Renames/moves an MSDOS file
  *
  */
 
 
-#define LOWERCASE
-
 #include "sysincludes.h"
 #include "msdos.h"
 #include "mtools.h"
@@ -35,17 +48,16 @@ typedef struct Arg_t {
  * Open the named file for read, create the cluster chain, return the
  * directory structure or NULL on error.
  */
-int renameit(char *dosname,
-	     char *longname,
-	     void *arg0,
-	     direntry_t *targetEntry)
+static int renameit(dos_name_t *dosname,
+		    char *longname UNUSEDP,
+		    void *arg0,
+		    direntry_t *targetEntry)
 {
 	Arg_t *arg = (Arg_t *) arg0;
 	int fat;
 
 	targetEntry->dir = arg->entry->dir;
-	strncpy(targetEntry->dir.name, dosname, 8);
-	strncpy(targetEntry->dir.ext, dosname + 8, 3);
+	dosnameToDirentry(dosname, &targetEntry->dir);
 
 	if(IS_DIR(targetEntry)) {
 		direntry_t *movedEntry;
@@ -87,10 +99,8 @@ int renameit(char *dosname,
 				}
 				break;
 			}
-			
-			/* wipe out original entry */			
-			movedEntry->dir.name[0] = DELMARK;
-			dir_write(movedEntry);
+
+			wipeEntry(movedEntry);
 			
 			/* free the old parent, allocate the new one. */
 			oldDir = movedEntry->Dir;
@@ -102,8 +112,7 @@ int renameit(char *dosname,
 	}
 
 	/* wipe out original entry */
-	arg->mp.direntry->dir.name[0] = DELMARK;
-	dir_write(arg->mp.direntry);
+	wipeEntry(arg->mp.direntry);
 	return 0;
 }
 
@@ -203,7 +212,8 @@ static int rename_oldsyntax(direntry_t *entry, MainParam_t *mp)
 }
 
 
-static void usage(void)
+static void usage(int ret) NORETURN;
+static void usage(int ret)
 {
 	fprintf(stderr,
 		"Mtools version %s, dated %s\n", mversion, mdate);
@@ -212,15 +222,16 @@ static void usage(void)
 	fprintf(stderr,
 		"       %s [-vV] [-D clash_option] file [files...] target_directory\n", 
 		progname);
-	exit(1);
+	exit(ret);
 }
 
+void mmove(int argc, char **argv, int oldsyntax) NORETURN;
 void mmove(int argc, char **argv, int oldsyntax)
 {
 	Arg_t arg;
 	int c;
-	char shortname[13];
-	char longname[VBUFSIZE];
+	char shortname[12*4+1];
+	char longname[4*MAX_VNAMELEN+1];
 	char def_drive;
 	int i;
 
@@ -230,27 +241,34 @@ void mmove(int argc, char **argv, int oldsyntax)
 
 	/* get command line options */
 	arg.verbose = 0;
-	while ((c = getopt(argc, argv, "vD:o")) != EOF) {
+	if(helpFlag(argc, argv))
+		usage(0);
+	while ((c = getopt(argc, argv, "i:vD:oh")) != EOF) {
 		switch (c) {
+			case 'i':
+				set_cmd_line_image(optarg);
+				break;
 			case 'v':	/* dummy option for mcopy */
 				arg.verbose = 1;
 				break;
-			case '?':
-				usage();
 			case 'o':
 				handle_clash_options(&arg.ch, c);
 				break;
 			case 'D':
 				if(handle_clash_options(&arg.ch, *optarg))
-					usage();
+					usage(1);
 				break;
+			case 'h':
+				usage(0);
+			case '?':
+				usage(1);
 			default:
 				break;
 		}
 	}
 
 	if (argc - optind < 2)
-		usage();
+		usage(1);
 
 	init_mp(&arg.mp);		
 	arg.mp.arg = (void *) &arg;
@@ -261,8 +279,8 @@ void mmove(int argc, char **argv, int oldsyntax)
 	for(i=optind; i<argc; i++)
 		if(argv[i][0] && argv[i][1] == ':' ){
 			if(!def_drive)
-				def_drive = toupper(argv[i][0]);
-			else if(def_drive != toupper(argv[i][0])){
+				def_drive = ch_toupper(argv[i][0]);
+			else if(def_drive != ch_toupper(argv[i][0])){
 				fprintf(stderr,
 					"Cannot move files across different drives\n");
 				exit(1);
@@ -275,7 +293,7 @@ void mmove(int argc, char **argv, int oldsyntax)
 	if (oldsyntax && (argc - optind != 2 || strpbrk(":/", argv[argc-1])))
 		oldsyntax = 0;
 
-	arg.mp.lookupflags = 
+	arg.mp.lookupflags =
 	  ACCEPT_PLAIN | ACCEPT_DIR | DO_OPEN_DIRS | NO_DOTS | NO_UNIX;
 
 	if (!oldsyntax){
