@@ -26,15 +26,15 @@ typedef struct dos_name_t dos_name_t;
 extern int lockf(int, int, off_t);  /* SCO has no proper include file for lockf */
 #endif 
 
-#define SCSI_FLAG 1
-#define PRIV_FLAG 2
-#define NOLOCK_FLAG 4
-#define USE_XDF_FLAG 8
-#define MFORMAT_ONLY_FLAG 16
-#define VOLD_FLAG 32
-#define FLOPPYD_FLAG 64
-#define FILTER_FLAG 128
-#define SWAP_FLAG 256 
+#define SCSI_FLAG		0x001u
+#define PRIV_FLAG		0x002u
+#define NOLOCK_FLAG		0x004u
+#define USE_XDF_FLAG		0x008u
+#define MFORMAT_ONLY_FLAG	0x010u
+#define VOLD_FLAG		0x020u
+#define FLOPPYD_FLAG		0x040u
+#define FILTER_FLAG		0x080u
+#define SWAP_FLAG		0x100u
 
 #define IS_SCSI(x)  ((x) && ((x)->misc_flags & SCSI_FLAG))
 #define IS_PRIVILEGED(x) ((x) && ((x)->misc_flags & PRIV_FLAG))
@@ -79,6 +79,27 @@ typedef struct device {
 	const char *cfg_filename; /* used for debugging purposes */
 } device_t;
 
+struct OldDos_t {
+	unsigned int tracks;
+	unsigned int sectors;
+	unsigned int heads;
+	
+	unsigned int dir_len;
+	unsigned int cluster_size;
+	unsigned int fat_len;
+
+	int media;
+};
+
+extern struct OldDos_t *getOldDosBySize(size_t size);
+extern struct OldDos_t *getOldDosByMedia(int media);
+extern struct OldDos_t *getOldDosByParams(unsigned int tracks,
+					  unsigned int heads,
+					  unsigned int sectors,
+					  unsigned int dir_len,
+					  unsigned int cluster_size);
+int setDeviceFromOldDos(int media, struct device *dev);
+
 
 #ifndef OS_linux
 #define BOOTSIZE 512
@@ -94,6 +115,12 @@ typedef struct doscp_t doscp_t;
 extern const char *short_illegals, *long_illegals;
 
 #define maximize(target, max) do { \
+  if(target > max) { \
+    target = max; \
+  } \
+} while(0)
+
+#define smaximize(target, max) do {		\
   if(max < 0) { \
     if(target > 0) \
       target = 0; \
@@ -102,6 +129,15 @@ extern const char *short_illegals, *long_illegals;
   } \
 } while(0)
 
+#define sizemaximize(target, max) do {		\
+  if(max < 0) { \
+    if(target > 0) \
+      target = 0; \
+  } else if(target > (size_t) max) {		\
+    target = max; \
+  } \
+} while(0)
+
 #define minimize(target, min) do { \
   if(target < min) \
     target = min; \
@@ -125,11 +161,11 @@ int lock_dev(int fd, int mode, struct device *dev);
 char *unix_normalize (doscp_t *cp, char *ans, struct dos_name_t *dn);
 void dos_name(doscp_t *cp, const char *filename, int verbose, int *mangled,
 	      struct dos_name_t *);
-struct directory *mk_entry(const dos_name_t *filename, char attr,
+struct directory *mk_entry(const dos_name_t *filename, unsigned char attr,
 			   unsigned int fat, size_t size, time_t date,
 			   struct directory *ndir);
 
-struct directory *mk_entry_from_base(const char *base, char attr,
+struct directory *mk_entry_from_base(const char *base, unsigned char attr,
 				     unsigned int fat, size_t size, time_t date,
 				     struct directory *ndir);
 
@@ -155,7 +191,14 @@ extern int got_signal;
 #define got_signal do_gotsignal(__FILE__, __LINE__) */
 
 void setup_signal(void);
+#ifdef HAVE_SIGACTION
+typedef struct { struct sigaction sa[4]; } saved_sig_state;
+#else
+typedef int saved_sig_state;
+#endif
 
+void allow_interrupts(saved_sig_state *ss);
+void restore_interrupts(saved_sig_state *ss);
 
 #define SET_INT(target, source) \
 if(source)target=source
@@ -166,10 +209,23 @@ UNUSED(static __inline__ int compare (long ref, long testee))
 	return (ref && ref != testee);
 }
 
+UNUSED(static __inline__ char ch_toupper(char ch))
+{
+        return (char) toupper( (unsigned char) ch);
+}
+
+UNUSED(static __inline__ char ch_tolower(char ch))
+{
+        return (char) tolower( (unsigned char) ch);
+}
+
 Stream_t *GetFs(Stream_t *Fs);
 
-void label_name(doscp_t *cp, const char *filename, int verbose, 
-		int *mangled, dos_name_t *ans);
+void label_name_uc(doscp_t *cp, const char *filename, int verbose, 
+		   int *mangled, dos_name_t *ans);
+
+void label_name_pc(doscp_t *cp, const char *filename, int verbose, 
+		   int *mangled, dos_name_t *ans);
 
 /* environmental variables */
 extern unsigned int mtools_skip_check;
@@ -178,6 +234,7 @@ extern unsigned int mtools_ignore_short_case;
 extern unsigned int mtools_no_vfat;
 extern unsigned int mtools_numeric_tail;
 extern unsigned int mtools_dotted_dir;
+extern unsigned int mtools_lock_timeout;
 extern unsigned int mtools_twenty_four_hour_clock;
 extern const char *mtools_date_string;
 extern unsigned int mtools_rate_0, mtools_rate_any;
@@ -187,12 +244,12 @@ extern int mtools_raw_tty;
 extern int batchmode;
 
 char get_default_drive(void);
-void set_cmd_line_image(char *img, int flags);
+void set_cmd_line_image(char *img);
 void read_config(void);
 off_t str_to_offset(char *str);
 extern struct device *devices;
 extern struct device const_devices[];
-extern const int nr_const_devices;
+extern const unsigned int nr_const_devices;
 
 #define New(type) ((type*)(calloc(1,sizeof(type))))
 #define Grow(adr,n,type) ((type*)(realloc((char *)adr,n*sizeof(type))))
@@ -241,7 +298,7 @@ char *getVoldName(struct device *dev, char *name);
 #endif
 
 
-Stream_t *OpenDir(Stream_t *Parent, const char *filename);
+Stream_t *OpenDir(const char *filename);
 /* int unix_dir_loop(Stream_t *Stream, MainParam_t *mp); 
 int unix_loop(MainParam_t *mp, char *arg); */
 
