@@ -15,10 +15,13 @@
  *  along with Mtools.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-const char *mversion="pre-4.0.20";
+#include "sysincludes.h"
+#include "msdos.h"
+
+const char *mversion="4.0.22";
 
 /* Multiple releases on same day should be marked with (b), (cd), (d) after
  * date string below */
-const char *mdate = "November 11th, 2018";
+const char *mdate = "December 2nd, 2018";
 
-const char *mformat_banner = "MTOO4020";
+const char *mformat_banner = "MTOO4022";
