@@ -1,3 +1,20 @@
+/*  Copyright 1996,1997,1999,2001,2002,2008,2009 Alain Knaff.
+ *  This file is part of mtools.
+ *
+ *  Mtools is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Mtools is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with Mtools.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 #include "sysincludes.h"
 #include "msdos.h"
 #include "stream.h"
@@ -63,3 +80,8 @@ int write_pass_through(Stream_t *Stream, char *buf, mt_off_t start, size_t len)
 {
 	return WRITES(Stream->Next, buf, start, len);
 }
+
+doscp_t *get_dosConvert_pass_through(Stream_t *Stream)
+{
+	return GET_DOSCONVERT(Stream->Next);
+}
